=======
History
=======

0.4.0 (2023-02-02)
------------------

* Add eligible queued metrics
* Bump package versions


0.3.0 (2020-10-28)
------------------

* Updated required version of ViewClust
* Added numerous figures to show_job_use diagnostics
* Added ability to return figure handles of all show_job_use figures
* Linting fixes EVERYWHERE


0.2.2 (2020-07-25)
------------------

* Reworked default use_unit queries - tries to infer proper use_unit from context!


0.2.1 (2020-07-15)
------------------

* Formatting fixes for show job use suite


0.2.0 (2020-07-13)
------------------

* Added show job use account diagnostic suite


0.1.1 (2020-06-25)
------------------

* Added migrated files
* Fixed doc building


0.1.0 (2020-06-24)
------------------

* First release on PyPI.
